pitcharraytools.PitchArray
==========================

.. inheritance-diagram:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray
   :private-bases:

.. autoclass:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.cell_tokens_by_row

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.cell_widths_by_row

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.cells

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.columns

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.depth

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.dimensions

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.has_voice_crossing

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.is_rectangular

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pitches

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pitches_by_row

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.rows

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.size

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.voice_crossing_count

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.weight

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.width

Methods
-------

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.append_column

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.append_row

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.apply_pitches_by_row

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.copy_subarray

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.has_spanning_cell_over_index

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pad_to_depth

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pad_to_width

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pop_column

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pop_row

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.remove_row

Special Methods
---------------

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__add__

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__contains__

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__eq__

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__getitem__

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__iadd__

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__ne__

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__repr__

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__setitem__

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__str__
